pub fn lex_simple(code: &str) -> Result<CirruLexItemList, String>👎Deprecated since 0.2.0:
Use lex() instead which provides better error information
Backward compatibility function for lex that returns tokens with String error
pub fn lex_simple(code: &str) -> Result<CirruLexItemList, String>Use lex() instead which provides better error information
Backward compatibility function for lex that returns tokens with String error